package # IGNORE ME PAUSE
    My::Test::WithViolations;

use strict;
use warnings;

my $FOO;

sub test {
    my $x;
    return [];
}

1;

__END__

=pod

=cut
